@@ -1,7 +1,7 @@
 
 /*
  * GNU Typist  - interactive typing tutor program for UNIX systems
- * Copyright (C) 1998,2001  Simon Baldwin (simonb@sco.com)
+ * Copyright (C) 1998, 1999, 2000, 2001, 2002  Simon Baldwin (simonb@sco.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -133,8 +133,8 @@ char *SPEED_PCT_ERROR;
 char *YN;
 char *RNE;
 
-#ifndef PACKAGE_DATA_DIR
-#define PACKAGE_DATA_DIR "."
+#ifndef DATADIR
+#define DATADIR "."
 #endif
 
 #define	DEFAULT_SCRIPT      "gtypist.typ"
@@ -331,6 +331,8 @@ fatal_error( char *message, char *line ) {
 	   message );
   if ( line != NULL )
     fprintf( stderr, ":\n%s\n", line );
+  else
+    fprintf( stderr, "\n" );
   exit( 1 );
 }
 
@@ -585,7 +587,7 @@ do_keybind( FILE *script, char *line ) {
      the syntax and correctness of the mappings */
   label = (char*)malloc( strlen(SCR_DATA( line )) + 1 );
   if ( sscanf( SCR_DATA( line ), "%d:%s", &fkey, label ) != 2 )
-    fatal_error( _("invalid key binding (%d:%s)"), line );
+    fatal_error( _("invalid key binding"), line );
   if ( fkey < 1 || fkey > NFKEYS )
     fatal_error( _("invalid function key number"), line );
   
@@ -1460,13 +1462,17 @@ do_error_max_set( FILE *script, char *line )
 	    --data;
 	  }
 	if (*data == '%')
+	  /* xgettext: no-c-format */
 	  fatal_error( _("'*' must immediately follow '%'"), copy_of_line );
 	else
+	  /* xgettext: no-c-format */
 	  fatal_error( _("missing '%'"), copy_of_line );
       } else
+	/* xgettext: no-c-format */
 	fatal_error( _("missing '%'"), copy_of_line );
     }
     if (isspace( *(data - 1) ))
+      /* xgettext: no-c-format */
       fatal_error( _("'%' must immediately follow value"), copy_of_line );
     /* remove '%' */
     *data = '\0';
@@ -1703,7 +1709,7 @@ print_help()
       "-q",
       "-l L",
       "-w",
-      "-k"
+      "-k",
       "-h",
       "-v" };
   char *lop[]= 
@@ -1747,7 +1753,7 @@ print_help()
     }
 
   printf(_("\nIf not supplied, script-file defaults to '%s/%s'.\n")
-	 ,PACKAGE_DATA_DIR,DEFAULT_SCRIPT);
+	 ,DATADIR,DEFAULT_SCRIPT);
   printf(_("The path $GTYPIST_PATH is searched for script files.\n\n"));
 
   printf("%s:\n",_("Examples"));
@@ -1787,7 +1793,7 @@ parse_cmdline( int argc, char **argv ) {
     { 0, 0, 0, 0 }};
 
   /* process every option */
-  while ( (c=getopt_long( argc, argv, "e:ntf:c:sql:whv",
+  while ( (c=getopt_long( argc, argv, "e:ntf:c:sql:wkhv",
 			  long_options, &option_index )) != -1 ) 
     {
       switch (c)
@@ -1904,11 +1910,11 @@ int main( int argc, char **argv )
   
 #if defined(ENABLE_NLS) && defined(LC_ALL)
   setlocale (LC_ALL, "");
-  bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+  bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 #endif
 
-  COPYRIGHT=_("Copyright (C) 1998,2001  Simon Baldwin.\n\
+  COPYRIGHT=_("Copyright (C) 1998, 1999, 2000, 2001, 2002 Simon Baldwin.\n\
 This program comes with ABSOLUTELY NO WARRANTY; for details\n\
 please see the file 'COPYING' supplied with the source code.\n\
 This is free software, and you are welcome to redistribute it\n\
@@ -1998,7 +2004,7 @@ This program is released under the GNU General Public License.");
   if ( argc - optind == 1 )
     strcpy( script_file, argv[optind] );
   else
-    sprintf( script_file,"%s/%s",PACKAGE_DATA_DIR,DEFAULT_SCRIPT);
+    sprintf( script_file,"%s/%s",DATADIR,DEFAULT_SCRIPT);
   
   script = fopen( script_file, "r" );
   if (script==NULL && getenv( "GTYPIST_PATH" ) != NULL ) 
@@ -2016,7 +2022,7 @@ This program is released under the GNU General Public License.");
     }
   if (script==NULL)
     {
-      strcpy( filepath, PACKAGE_DATA_DIR );
+      strcpy( filepath, DATADIR );
       strcat( filepath, "/" );
       strcat( filepath, script_file );
       script = fopen( filepath, "r" );
